var monitor = (function () {
    var CLIENT_ID_IOS = 4;
    var CLIENT_ID_ANDROID = 3;
    var CLIENT_ID_WEB = 8;

    var client_id;

    if (window.is_btime && $utils.browsers.android) {
        client_id = CLIENT_ID_ANDROID;
    } else if (window.is_btime && $utils.browsers.ios) {
        client_id = CLIENT_ID_IOS;
    } else {
        client_id = CLIENT_ID_WEB;
    }

    var base = {
        ts: Date.now(),
        mid: '0',
        uid: '0',
        login_id: '0',
        net: '0',
        client_id: client_id,
        version: '0'
    };

    var setBase = function (obj) {
        if (typeof obj == 'string') {
            try {
                obj = JSON.parse(obj);
            } catch (e) {
                console.error(e);
                obj = {};
            }
        }

        console.log(obj);

        base.mid = obj.mid;
        base.uid = obj.uid;
        base.login_id = obj.login_id;
        base.net = obj.net;
        base.client_id = obj.client_id;
        base.version = obj.version;
    };

    var makeLogParams = function (obj) {
        return Object.assign({}, base, obj);
    };

    /**
     * 点击搜索
     * @param options => keyword:"",string型,搜索的关键词
     */
    var log_search = function (options) {
        options = options || {};
        options.action = 'search';
        $webFunc.webLog(makeLogParams(options));
    };

    /**
     * 搜索框展示/点击次数，输入字符次数，删除输入框(删除输入的字符串)
     * @param options => type: int型,1=>展示，2=>点击,3=>输入字符串（点击输入框后，输入字符串，无论多少字符串、以及之后又对字符串做了多少次删除操作，都算作一次输入操作），4=>单字删除输入框的字符串，5=>点击搜索框的删除按钮
     */
    var log_search_input = function (options) {
        options = options || {};
        options.action = 'search_input';
        $webFunc.webLog(makeLogParams(options));
    };

    /**
     * 搜索页面，展示次数
     * @param options
     */
    var log_search_page = function (options) {
        options = options || {};
        options.action = 'search_page';
        $webFunc.webLog(makeLogParams(options));
    };

    /**
     * 搜索页面，返回按钮点击次数
     * @param options
     */
    var log_search_back_btn = function (options) {
        options = options || {};
        options.action = 'search_back_btn';
        $webFunc.webLog(makeLogParams(options));
    };

    /**
     * 搜索页面，大家都在搜点击次数
     * @param options => keyword:"",string型，点击的搜索词
     */
    var log_hot_search = function (options) {
        options = options || {};
        options.action = 'hot_search';
        $webFunc.webLog(makeLogParams(options));
    };

    /**
     * 搜索页面，搜索历史点击次数
     * @param options => keyword:"",string型，点击的搜索历史词
     */
    var log_search_history = function (options) {
        options = options || {};
        options.action = 'search_history';
        $webFunc.webLog(makeLogParams(options));
    };

    /**
     * 搜索页面，搜索结果页展示次数（无论点击搜索、大家都在搜还是搜索历史词）
     * @param options
     */
    var log_search_result = function (options) {
        options = options || {};
        options.action = 'search_result';
        $webFunc.webLog(makeLogParams(options));
    };

    /**
     * 搜索页面，删除搜索历史
     * @param options => type:0,int型，删除的操作方式，0=>删除单条(搜索历史词后的"X")，1=>点击"清楚全部历史"按钮
     */
    var log_search_history_del = function (options) {
        options = options || {};
        options.action = 'search_history_del';
        $webFunc.webLog(makeLogParams(options));
    };

    /**
     * 搜索结果点击次数
     * @param options => type:0,int型，点击搜索结果的类型，0=>频道,1=>百科,2=>时间号,3=>点击"更多相关时间号",4=>视频,5=>点击"更多相关视频",6=>新闻（无图、图文、图集、视频、直播、专题）
     *                => channel_id:"",string型，频道id，如果type为0=>频道，填频道id，否则填空字符串
     *                => gid:"",string型，新闻gid，如果type为4=>视频或6=>新闻，填新闻gid，否则填空字符串
     */
    var log_search_result_click = function (options) {
        options = options || {};
        options.action = 'search_result_click';
        $webFunc.webLog(makeLogParams(options));
    };


    return {
        setBase: setBase,
        log: {
            search: log_search,
            search_input: log_search_input,
            search_page: log_search_page,
            search_back_btn: log_search_back_btn,
            hot_search: log_hot_search,
            search_history: log_search_history,
            search_result: log_search_result,
            search_history_del: log_search_history_del,
            search_result_click: log_search_result_click
        }
    }
})();